==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QRayCasterHit.java <==
package io.qt.qt3d.render;


/**
 * <p>Details of a hit when casting a ray through a model</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html">Qt3DRender::QRayCasterHit</a></p>
 */
public class QRayCasterHit extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRayCasterHit.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#HitType-enum">Qt3DRender::QRayCasterHit::HitType</a></p>
     */
    public enum HitType implements io.qt.QtEnumerator {
        TriangleHit(0),
        LineHit(1),
        PointHit(2),
        EntityHit(3);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private HitType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static HitType resolve(int value) {
            switch (value) {
            case 0: return TriangleHit;
            case 1: return LineHit;
            case 2: return PointHit;
            case 3: return EntityHit;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public QRayCasterHit(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QRayCasterHit instance);
    
    @SuppressWarnings({"exports"})
    public QRayCasterHit(io.qt.qt3d.render.QRayCasterHit.HitType type, io.qt.qt3d.core.QNodeId id, float distance, io.qt.gui.QVector3D localIntersect, io.qt.gui.QVector3D worldIntersect, int primitiveIndex, int v1, int v2, int v3){
        super((QPrivateConstructor)null);
        initialize_native(this, type, id, distance, localIntersect, worldIntersect, primitiveIndex, v1, v2, v3);
    }
    
    private native static void initialize_native(QRayCasterHit instance, io.qt.qt3d.render.QRayCasterHit.HitType type, io.qt.qt3d.core.QNodeId id, float distance, io.qt.gui.QVector3D localIntersect, io.qt.gui.QVector3D worldIntersect, int primitiveIndex, int v1, int v2, int v3);
    
    public QRayCasterHit(io.qt.qt3d.render.QRayCasterHit other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QRayCasterHit instance, io.qt.qt3d.render.QRayCasterHit other);
    
    /**
     * <p>Returns the distance between the origin of the ray and the intersection point</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#distance">Qt3DRender::QRayCasterHit::distance()const</a></p>
     */
    @io.qt.QtUninvokable
    public final float distance(){
        return distance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float distance_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns a pointer to the entity that was hit</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#entity">Qt3DRender::QRayCasterHit::entity()const</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QEntity entity(){
        return entity_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QEntity entity_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the id of the entity that was hit</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#entityId">Qt3DRender::QRayCasterHit::entityId()const</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId entityId(){
        return entityId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId entityId_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the coordinates of the intersection point in the entity's coordinate system</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#localIntersection">Qt3DRender::QRayCasterHit::localIntersection()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D localIntersection(){
        return localIntersection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D localIntersection_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the index of the picked primitive</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#primitiveIndex">Qt3DRender::QRayCasterHit::primitiveIndex()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int primitiveIndex(){
        return primitiveIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int primitiveIndex_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the type of the hit</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#type">Qt3DRender::QRayCasterHit::type()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRayCasterHit.HitType type(){
        return io.qt.qt3d.render.QRayCasterHit.HitType.resolve(type_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int type_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the index of the first vertex of the picked primitive</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#vertex1Index">Qt3DRender::QRayCasterHit::vertex1Index()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int vertex1Index(){
        return vertex1Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex1Index_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the index of the second vertex of the picked primitive</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#vertex2Index">Qt3DRender::QRayCasterHit::vertex2Index()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int vertex2Index(){
        return vertex2Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex2Index_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the index of the third vertex of the picked primitive</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#vertex3Index">Qt3DRender::QRayCasterHit::vertex3Index()const</a></p>
     */
    @io.qt.QtUninvokable
    public final int vertex3Index(){
        return vertex3Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex3Index_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the coordinates of the intersection point in the model's coordinate system</p>
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qraycasterhit.html#worldIntersection">Qt3DRender::QRayCasterHit::worldIntersection()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D worldIntersection(){
        return worldIntersection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D worldIntersection_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRayCasterHit(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QRayCasterHit clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QRayCasterHit clone_native(long __this_nativeId);
}

==> qtjambi-qt3drender-6.2.6-sources.jar: io/qt/qt3d/render/QRayCasterHit.java <==
package io.qt.qt3d.render;


/**
 * <p>Details of a hit when casting a ray through a model</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html">Qt3DRender::QRayCasterHit</a></p>
 */
public class QRayCasterHit extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRayCasterHit.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#HitType-enum">Qt3DRender::QRayCasterHit::HitType</a></p>
     */
    public enum HitType implements io.qt.QtEnumerator {
        TriangleHit(0),
        LineHit(1),
        PointHit(2),
        EntityHit(3);

        private HitType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static HitType resolve(int value) {
            switch (value) {
            case 0: return TriangleHit;
            case 1: return LineHit;
            case 2: return PointHit;
            case 3: return EntityHit;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public QRayCasterHit(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QRayCasterHit instance);
    
    @SuppressWarnings({"exports"})
    public QRayCasterHit(io.qt.qt3d.render.QRayCasterHit.HitType type, io.qt.qt3d.core.QNodeId id, float distance, io.qt.gui.QVector3D localIntersect, io.qt.gui.QVector3D worldIntersect, int primitiveIndex, int v1, int v2, int v3){
        super((QPrivateConstructor)null);
        initialize_native(this, type, id, distance, localIntersect, worldIntersect, primitiveIndex, v1, v2, v3);
    }
    
    private native static void initialize_native(QRayCasterHit instance, io.qt.qt3d.render.QRayCasterHit.HitType type, io.qt.qt3d.core.QNodeId id, float distance, io.qt.gui.QVector3D localIntersect, io.qt.gui.QVector3D worldIntersect, int primitiveIndex, int v1, int v2, int v3);
    
    public QRayCasterHit(io.qt.qt3d.render.QRayCasterHit other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QRayCasterHit instance, io.qt.qt3d.render.QRayCasterHit other);
    
    /**
     * <p>Returns the distance between the origin of the ray and the intersection point</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#distance">Qt3DRender::QRayCasterHit::distance()const</a></p>
     */
    @io.qt.QtPropertyReader(name="distance")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final float distance(){
        return distance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float distance_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns a pointer to the entity that was hit</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#entity">Qt3DRender::QRayCasterHit::entity()const</a></p>
     */
    @io.qt.QtPropertyReader(name="entity")
    @io.qt.QtPropertyConstant
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QEntity entity(){
        return entity_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QEntity entity_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the id of the entity that was hit</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#entityId">Qt3DRender::QRayCasterHit::entityId()const</a></p>
     */
    @io.qt.QtPropertyReader(name="entityId")
    @io.qt.QtPropertyConstant
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId entityId(){
        return entityId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId entityId_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the coordinates of the intersection point in the entity's coordinate system</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#localIntersection">Qt3DRender::QRayCasterHit::localIntersection()const</a></p>
     */
    @io.qt.QtPropertyReader(name="localIntersection")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D localIntersection(){
        return localIntersection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D localIntersection_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the index of the picked primitive</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#primitiveIndex">Qt3DRender::QRayCasterHit::primitiveIndex()const</a></p>
     */
    @io.qt.QtPropertyReader(name="primitiveIndex")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int primitiveIndex(){
        return primitiveIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int primitiveIndex_native_constfct(long __this__nativeId);
    
    public final java.lang.String toString(){
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native java.lang.String toString_native(long __this__nativeId);
    
    /**
     * <p>Returns the type of the hit</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#type">Qt3DRender::QRayCasterHit::type()const</a></p>
     */
    @io.qt.QtPropertyReader(name="type")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QRayCasterHit.HitType type(){
        return io.qt.qt3d.render.QRayCasterHit.HitType.resolve(type_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int type_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the index of the first vertex of the picked primitive</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#vertex1Index">Qt3DRender::QRayCasterHit::vertex1Index()const</a></p>
     */
    @io.qt.QtPropertyReader(name="vertex1Index")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int vertex1Index(){
        return vertex1Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex1Index_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the index of the second vertex of the picked primitive</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#vertex2Index">Qt3DRender::QRayCasterHit::vertex2Index()const</a></p>
     */
    @io.qt.QtPropertyReader(name="vertex2Index")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int vertex2Index(){
        return vertex2Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex2Index_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the index of the third vertex of the picked primitive</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#vertex3Index">Qt3DRender::QRayCasterHit::vertex3Index()const</a></p>
     */
    @io.qt.QtPropertyReader(name="vertex3Index")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final int vertex3Index(){
        return vertex3Index_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int vertex3Index_native_constfct(long __this__nativeId);
    
    /**
     * <p>Returns the coordinates of the intersection point in the model's coordinate system</p>
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qraycasterhit.html#worldIntersection">Qt3DRender::QRayCasterHit::worldIntersection()const</a></p>
     */
    @io.qt.QtPropertyReader(name="worldIntersection")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.gui.QVector3D worldIntersection(){
        return worldIntersection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QVector3D worldIntersection_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRayCasterHit(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QRayCasterHit clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QRayCasterHit clone_native(long __this_nativeId);
}
